@@ -15,7 +15,7 @@ from socket import (
 )
 from threading import Timer
 from time import sleep
-from wsgiref.simple_server import WSGIRequestHandler
+from ph_wsgiref.simple_server import WSGIRequestHandler
 
 from .resource_balancer import ResourceBalancer
 
@@ -59,16 +59,16 @@ class Server:
             ) as s, self.balancer.acquire_addr() as addr:
                 try:
                     s.connect(addr)
+
+                    s.setsockopt(SOL_SOCKET, SO_KEEPALIVE, 1)
+                    s.setsockopt(IPPROTO_TCP, TCP_KEEPIDLE, 1)
+                    s.setsockopt(IPPROTO_TCP, TCP_KEEPINTVL, 2)
+                    s.setsockopt(IPPROTO_TCP, TCP_KEEPCNT, 3)
                 except Exception as e:
                     error("Connect: %s", e)
                     sleep(2)
                     continue
 
-                s.setsockopt(SOL_SOCKET, SO_KEEPALIVE, 1)
-                s.setsockopt(IPPROTO_TCP, TCP_KEEPIDLE, 1)
-                s.setsockopt(IPPROTO_TCP, TCP_KEEPINTVL, 2)
-                s.setsockopt(IPPROTO_TCP, TCP_KEEPCNT, 3)
-
                 try:
                     Handler(s, addr, server)
                 except:
